package com.ruoyi.web.controller.system.count;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TdPropertyInfo;
import com.ruoyi.system.domain.TdPropertyManager;
import com.ruoyi.system.domain.count.PropertyDesCountDTO;
import com.ruoyi.system.domain.count.PropertyStateCountDTO;
import com.ruoyi.system.domain.count.UserCountDTO;
import com.ruoyi.system.domain.count.UserSmCountDTO;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.system.service.ITdPropertyInfoService;
import com.ruoyi.system.service.ITdPropertyManagerService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Collectors;

@Controller
@RequestMapping("/system/propertynum")
public class SysPropertynumController extends BaseController {
    private String prefix = "system/property/propertynum";
    @Autowired
    private ITdPropertyManagerService tdPropertyManagerService;
    @Autowired
    private ITdPropertyInfoService tdPropertyInfoService;

    @RequiresPermissions("system:propertynum:view")
    @GetMapping()
    public String property()
    {
        return prefix + "/propertynum";
    }

    /**
     * 查询资产登记列表
     */
    @RequiresPermissions("system:propertynum:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdPropertyManager tdPropertyManager)
    {
        startPage();
        List<TdPropertyManager> list = tdPropertyManagerService.selectTdPropertyManagerList(tdPropertyManager);
        return getDataTable(list);
    }

    /**
     * 打印界面
     */
    @RequiresPermissions("system:propertynum:print")
    @GetMapping("/print/{useId}")
    @Log(title = "资产设备统计", businessType = BusinessType.PRINT)
    public String print(@PathVariable("useId") String useId, ModelMap mmap)
    {
        List<TdPropertyInfo> tdPropertyInfos = tdPropertyInfoService.selectTdPropertyInfoByUseId(useId);
        TdPropertyManager tdPropertyManager = tdPropertyManagerService.selectTdPropertyManagerByUseId(useId);
        mmap.put("tdPropertyInfos", tdPropertyInfos);
        mmap.put("tdPropertyManager", tdPropertyManager);
        mmap.put("sysuser", getSysUser());
        return prefix + "/print";
    }

    @Autowired
    private ISysDictDataService dictDataService;
    
    /**
     * 
     *  资产统计
     * @return com.ruoyi.common.core.domain.AjaxResult
     */
    
    @PostMapping("/countInfo")
    @ResponseBody
    public AjaxResult countInfo() {
        SysDictData sysDictData =  new SysDictData();
        sysDictData.setDictType("sys_sm_property");
        List<SysDictData> smType = dictDataService.selectDictDataList(sysDictData);
        List<String> list = smType.stream().map(SysDictData::getDictLabel).collect(Collectors.toList());
        List<Long> yAxisData = new ArrayList<>();
        smType.forEach(xAxis -> {
            AtomicReference<Long> yAxis = new AtomicReference<>(0L);
             Integer count = tdPropertyInfoService.lambdaQuery()
                     .eq(TdPropertyInfo::getPropertyType, xAxis.getDictValue())
                     .count();
            yAxis.set(Long.valueOf(count));

            yAxisData.add(yAxis.get());
        });
        JSONObject obj = new JSONObject();
        obj.put("xAxisData", list.toArray());
        obj.put("yAxisData", yAxisData);
        return AjaxResult.success(obj);
    }

    private List<String> bf = Arrays.asList("未报废", "已报废");

    private List<String> xh = Arrays.asList("未销毁", "已销毁");

    /**
     *
     *  统计资产报废统计
     * @return com.ruoyi.common.core.domain.AjaxResult
     */
    @PostMapping("/countBF")
    @ResponseBody
    public AjaxResult countbf() {
        PropertyStateCountDTO propertyStateCountDTO = tdPropertyInfoService.selectCountBF();
        List<JSONObject> datas = bf.stream()
                .map(name -> {
                    AtomicReference<Object> value = new AtomicReference<>(0L);
                    if("未报废".equals(name)){
                        value.set(propertyStateCountDTO.getWbf());
                    }else{
                        value.set(propertyStateCountDTO.getYbf());
                    }
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put("value", value.get());
                    jsonObject.put("name", name);
                    return jsonObject;
                })
                .collect(Collectors.toList());
        return AjaxResult.success(datas);
    }
    /**
     *
     *  统计资产销毁统计
     * @return com.ruoyi.common.core.domain.AjaxResult
     */
    @PostMapping("/countXH")
    @ResponseBody
    public AjaxResult countXH() {
        PropertyDesCountDTO propertyDesCountDTO = tdPropertyInfoService.selectCountXH();
        List<JSONObject> datas = xh.stream()
                .map(name -> {
                    AtomicReference<Object> value = new AtomicReference<>(0L);
                    if("未销毁".equals(name)){
                        value.set(propertyDesCountDTO.getWxh());
                    }else{
                        value.set(propertyDesCountDTO.getYxh());
                    }
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put("value", value.get());
                    jsonObject.put("name", name);
                    return jsonObject;
                })
                .collect(Collectors.toList());
        return AjaxResult.success(datas);
    }

}
